summaryrefslogtreecommitdiffstats
path: root/lib/qextfileinfo.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit6c79d50fa9fbdff7f69ca57a8ab5fcc942375593 (patch)
treef47737d56c3239a0d8bc600674f0ca04b6e30d6e /lib/qextfileinfo.h
parent36c36b53a129509d56fdaa0a7c9fcbcacd0c5826 (diff)
downloadtdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.tar.gz
tdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/qextfileinfo.h')
-rw-r--r--lib/qextfileinfo.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/qextfileinfo.h b/lib/qextfileinfo.h
index 6a9e52c7..a223438e 100644
--- a/lib/qextfileinfo.h
+++ b/lib/qextfileinfo.h
@@ -55,21 +55,21 @@ public:
static KURL toRelative(const KURL& urlToConvert, const KURL& baseURL, bool resolveSymlinks = true);
/** Convert relative url to absolute, based on baseURL. */
static KURL toAbsolute(const KURL& urlToConvert, const KURL& baseURL);
- /** Returns a recursive list of files under path, matching the specified file tqmask. */
- static KURL::List allFiles( const KURL& path, const TQString &tqmask, TQWidget *window);
- /** Returns a recursive list of files under path, matching the specified file tqmask.
+ /** Returns a recursive list of files under path, matching the specified file mask. */
+ static KURL::List allFiles( const KURL& path, const TQString &mask, TQWidget *window);
+ /** Returns a recursive list of files under path, matching the specified file mask.
The returned urls are relative to path.
*/
- static KURL::List allFilesRelative( const KURL& path, const TQString &tqmask, TQWidget *window, bool resolveSymlinks = true);
- /** Returns a recursive list of files under path, matching the specified file tqmask.
+ static KURL::List allFilesRelative( const KURL& path, const TQString &mask, TQWidget *window, bool resolveSymlinks = true);
+ /** Returns a recursive list of files under path, matching the specified file mask.
The returned list contains detailed information about each url.
The user should delete the KFileItems and clear the dict
after they are not needed.
*/
- static TQDict<KFileItem> allFilesDetailed(const KURL& path, const TQString &tqmask, TQWidget *window);
+ static TQDict<KFileItem> allFilesDetailed(const KURL& path, const TQString &mask, TQWidget *window);
/** Creates a dir if don't exists. */
static bool createDir(const KURL & path, TQWidget *window);
- /** Returns the tqparent directory of dir. */
+ /** Returns the parent directory of dir. */
static KURL cdUp(const KURL &dir);
/** Returns the filename from a path string. */
static TQString shortName(const TQString &fname );
@@ -93,9 +93,9 @@ private:
bool internalExists(const KURL& url, bool readingOnly, TQWidget *window);
bool internalCopy(const KURL& src, const KURL& target, int permissions,
bool overwrite, bool resume, TQWidget* window);
- KURL::List allFilesInternal(const KURL& startURL, const TQString& tqmask, TQWidget *window);
- TQDict<KFileItem> allFilesDetailedInternal(const KURL& startURL, const TQString& tqmask, TQWidget *window);
- KURL::List allLocalFiles(const TQString& startPath, const TQString& tqmask);
+ KURL::List allFilesInternal(const KURL& startURL, const TQString& mask, TQWidget *window);
+ TQDict<KFileItem> allFilesDetailedInternal(const KURL& startURL, const TQString& mask, TQWidget *window);
+ KURL::List allLocalFiles(const TQString& startPath, const TQString& mask);
bool bJobOK;
static TQString lastErrorMsg;